@@ -4,7 +4,7 @@
 #
 # Author: Slaven Rezic
 #
-# Copyright (C) 2017,2018,2019 Slaven Rezic. All rights reserved.
+# Copyright (C) 2017,2018,2019,2020 Slaven Rezic. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
@@ -17,7 +17,8 @@ use warnings;
 
 {
     package Doit;
-    our $VERSION = '0.025_54';
+    our $VERSION = '0.025_55';
+    $VERSION =~ s{_}{};
 
     use constant IS_WIN => $^O eq 'MSWin32';
 }
@@ -42,7 +43,7 @@ use warnings;
 	    # XXX Probably should also check if the terminal is ANSI-capable at all
 	    # XXX Probably should not use coloring on non-terminals (but
 	    #     there could be a --color option like in git to force it)
-	    $can_coloring = !Doit::IS_WIN && eval { require Term::ANSIColor; 1 } ? 1 : 0;
+	    $can_coloring = !Doit::IS_WIN && ($ENV{TERM}||'') !~ m{^(|dumb)$} && eval { require Term::ANSIColor; 1 } ? 1 : 0;
 	}
     }
 
@@ -2116,6 +2117,7 @@ use warnings;
 	if (defined $umask && $umask !~ m{^\d+$}) {
 	    error "The umask '$umask' does not look correct, it should be a (possibly octal) number";
 	}
+	my $bootstrap = delete $opts{bootstrap};
 	error "Unhandled options: " . join(" ", %opts) if %opts;
 
 	my $self = bless { debug => $debug }, $class;
@@ -2140,6 +2142,11 @@ use warnings;
 	}
 	$self->{ssh} = $ssh;
 
+	if (($bootstrap||'') eq 'perl') {
+	    require Doit::Bootstrap;
+	    Doit::Bootstrap::_bootstrap_perl($self, dry_run => $dry_run);
+	}
+
 	{
 	    my $remote_cmd;
 	    if ($dest_os eq 'MSWin32') {
